@@ -30,7 +30,7 @@ class CoordsConfigDialog : public KConfigDialog
 {
     Q_OBJECT
 public:
-    explicit CoordsConfigDialog(QWidget *parent = 0);
+    explicit CoordsConfigDialog(QWidget *parent = nullptr);
     ~CoordsConfigDialog();
     /**
      * Updates the widgets containing the min/max values.
